@@ -641,11 +641,30 @@ func (k *Kubernetes) UpdateKubernetesObjects(name string, service kobject.Servic
 			securityContext.Privileged = &service.Privileged
 		}
 		if service.User != "" {
-			uid, err := strconv.ParseInt(service.User, 10, 64)
-			if err != nil {
-				log.Warn("Ignoring user directive. User to be specified as a UID (numeric).")
-			} else {
-				securityContext.RunAsUser = &uid
+			switch userparts := strings.Split(service.User, ":"); len(userparts) {
+			default:
+				log.Warn("Ignoring ill-formed user directive. Must be in format UID or UID:GID.")
+			case 1:
+				uid, err := strconv.ParseInt(userparts[0], 10, 64)
+				if err != nil {
+					log.Warn("Ignoring user directive. User to be specified as a UID (numeric).")
+				} else {
+					securityContext.RunAsUser = &uid
+				}
+			case 2:
+				uid, err := strconv.ParseInt(userparts[0], 10, 64)
+				if err != nil {
+					log.Warn("Ignoring user name in user directive. User to be specified as a UID (numeric).")
+				} else {
+					securityContext.RunAsUser = &uid
+				}
+
+				gid, err := strconv.ParseInt(userparts[1], 10, 64)
+				if err != nil {
+					log.Warn("Ignoring group name in user directive. Group to be specified as a GID (numeric).")
+				} else {
+					securityContext.RunAsGroup = &gid
+				}
 			}
 		}
 
@@ -792,7 +811,7 @@ func KomposeObjectToServiceConfigGroupMapping(komposeObject *kobject.KomposeObje
 // TranslatePodResource config pod resources
 func TranslatePodResource(service *kobject.ServiceConfig, template *api.PodTemplateSpec) {
 	// Configure the resource limits
-	if service.MemLimit != 0 || service.CPULimit != 0 {
+	if service.MemLimit != 0 || service.CPULimit != 0 || service.DeployLabels["kompose.ephemeral-storage.limit"] != "" {
 		resourceLimit := api.ResourceList{}
 
 		if service.MemLimit != 0 {
@@ -803,11 +822,18 @@ func TranslatePodResource(service *kobject.ServiceConfig, template *api.PodTempl
 			resourceLimit[api.ResourceCPU] = *resource.NewMilliQuantity(service.CPULimit, resource.DecimalSI)
 		}
 
+		// Check for ephemeral-storage in deploy labels
+		if val, ok := service.DeployLabels["kompose.ephemeral-storage.limit"]; ok {
+			if quantity, err := resource.ParseQuantity(val); err == nil {
+				resourceLimit[api.ResourceEphemeralStorage] = quantity
+			}
+		}
+
 		template.Spec.Containers[0].Resources.Limits = resourceLimit
 	}
 
 	// Configure the resource requests
-	if service.MemReservation != 0 || service.CPUReservation != 0 {
+	if service.MemReservation != 0 || service.CPUReservation != 0 || service.DeployLabels["kompose.ephemeral-storage.request"] != "" {
 		resourceRequests := api.ResourceList{}
 
 		if service.MemReservation != 0 {
@@ -818,6 +844,13 @@ func TranslatePodResource(service *kobject.ServiceConfig, template *api.PodTempl
 			resourceRequests[api.ResourceCPU] = *resource.NewMilliQuantity(service.CPUReservation, resource.DecimalSI)
 		}
 
+		// Check for ephemeral-storage in deploy labels
+		if val, ok := service.DeployLabels["kompose.ephemeral-storage.request"]; ok {
+			if quantity, err := resource.ParseQuantity(val); err == nil {
+				resourceRequests[api.ResourceEphemeralStorage] = quantity
+			}
+		}
+
 		template.Spec.Containers[0].Resources.Requests = resourceRequests
 	}
 }
